<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :bottomOffset="125"
        :ajaxFun="ajaxFun"
        ref="ifsLogTable"
      >
        <template #toolbar>
          <el-button
            type="primary"
            @click="executeIfs"
            v-if="permissions.basic_ifs_log_execute"
            >执行erp缓存</el-button
          >
          <el-button
            type="primary"
            @click="checkExecuteIfs"
            v-if="permissions.basic_ifs_log_check_execute"
            :loading="loadingExecuteIfs"
            >勾选执行erp缓存</el-button
          >
          <el-dropdown
            v-if="permissions.customerorder_state_change"
            @command="documentHandle"
            style="margin-left: 10px"
          >
            <el-button>
              erp缓存解析导出<i class="el-icon-arrow-down el-icon--right"></i>
            </el-button>
            <el-dropdown-menu slot="dropdown">
              <el-dropdown-item
                :key="item"
                :command="item.command"
                v-for="item in documentTagArr"
                :disabled="item.disabled"
                >{{ item.label }}</el-dropdown-item
              >
            </el-dropdown-menu>
          </el-dropdown>
        </template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
    </basic-container>
  </div>
</template>

<script>
import {
  fetchList,
  executeCaches,
  executeCachesById,
  ifsLogExport
} from '@/api/basic/ifslog'
import { mapGetters } from 'vuex'
import { transform } from '@/util/fileTransform'
import ttable from '@/views/common/ztt-table.vue'

export default {
  data() {
    return {
      ajaxFun: fetchList,
      multipleSelection: [],
      documentTagArr: [
        {
          label: '车间订单接收',
          command: 'IMPORT_SO_RECEIVE_STD',
          disabled: false
        },
        {
          label: '车间订单取消接收',
          command: 'IMPORT_SO_UNRECEIVE_STD',
          disabled: false
        },
        {
          label: '车间订单发料',
          command: 'IMPORT_SO_MATERIAL_ISSUE_STD',
          disabled: false
        },
        {
          label: '车间订单取消发料',
          command: 'IMPORT_SO_MATERIAL_UNISSUE_STD',
          disabled: false
        }
      ],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'ifslog',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 零件号
          {
            prop: 'url',
            label: '请求地址',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 名称
          {
            prop: 'procedureName',
            label: '方法名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件类型
          {
            prop: 'inAttr',
            label: '参数',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 单位
          {
            prop: 'result',
            label: '结果',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 单位
          {
            prop: 'state',
            label: '是否请求',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getMasterOptionList()
            },
            formatter: (row, column, cellValue) => {
              return cellValue == true ? '是' : '否'
            }
          },
          {
            prop: 'exceptionState',
            label: '是否出现异常',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getMasterOptionList()
            },
            formatter: (row, column, cellValue) => {
              return cellValue == true ? '是' : '否'
            }
          },
          // 描述
          {
            prop: 'mesParams',
            label: 'mes关联参数',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '200',
            prop: 'createTime',
            label: '时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [],
        operator: null,
        operatorConfig: {}
      },
      masterOptionList: [
        {
          value: true,
          label: '是'
        },
        {
          value: false,
          label: '否'
        }
      ],
      loadingExecuteIfs: false
    }
  },
  components: {
    ttable
  },
  created() {},
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    getMasterOptionList() {
      return this.masterOptionList
    },
    // 获取数据列表
    getData() {
      this.$refs.ifsLogTable.getDataList()
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    executeIfs() {
      executeCaches().then((response) => {
        this.getData()
      })
    },
    checkExecuteIfs() {
      this.loadingExecuteIfs = true
      if (this.multipleSelection.length > 0) {
        if (this.multipleSelection.length == 1) {
          const ifsLog = this.multipleSelection[0]
          if (!ifsLog.state) {
            executeCachesById(ifsLog.id)
              .then((response) => {
                this.loadingExecuteIfs = false
                this.getData()
              })
              .catch(() => {
                this.loadingExecuteIfs = false
              })
          } else {
            this.loadingExecuteIfs = false
            this.$message.error('只有未请求的，才能执行')
          }
        } else {
          this.loadingExecuteIfs = false
          this.$message.error('每次只能执行一条日志')
        }
      } else {
        this.loadingExecuteIfs = false
        this.$message.error('请先选择一条日志')
      }
    },
    // 导出
    documentHandle(event) {
      console.log(event)
      ifsLogExport({ type: event })
        .then((response) => {
          transform(response)
        })
        .catch(() => {})
    }
  }
}
</script>
